@@ -6,9 +6,9 @@
 using namespace Rcpp;
 
 List profitMaximization(List supplyFunction, DataFrame photosynthesisFunction, double Gswmin, double Gswmax);
-List transpirationBasic(List x, NumericVector meteovec,
+void transpirationBasic(List transpOutput, List x, NumericVector meteovec,  
                         double elevation, bool modifyInput = true);
-List transpirationAdvanced(List x, NumericVector meteovec,
+void transpirationAdvanced(List transpOutput, List x, NumericVector meteovec,
                   double latitude, double elevation, double slope, double aspect,
                   double solarConstant, double delta,
                   double canopyEvaporation = 0.0, double snowMelt = 0.0, double soilEvaporation = 0.0, double herbTranspiration = 0.0,
