@@ -294,7 +294,7 @@ void transpirationBasic(List transpOutput, List x, NumericVector meteovec,
     double lvpd_tmax = std::max(0.0, lvp_tmax - vpatm);
     double lvpd_tmin = std::max(0.0, lvp_tmin - vpatm);
     double E_gmin = Gswmin[c]*(lvpd_tmin+lvpd_tmax)/(2.0*Patm); // mol·s-1·m-2
-    // double E_cut = E_gmin*LAIphe[c]*(24.0*3600.0*0.018);
+    double E_gmin_day = E_gmin*LAIphe[c]*(24.0*3600.0*0.018); //L·d-1·m-2 = mm·d-1
     
     //Extraction from soil (can later be modified if there are changes in plant water content)
     if(!plantWaterPools) {
@@ -311,7 +311,7 @@ void transpirationBasic(List transpOutput, List x, NumericVector meteovec,
       double sumKunlc = sum(Kunlc);
       double Klcmean = sum(Klc*V(c,_));
       for(int l=0;l<nlayers;l++) {
-        outputExtraction(c,l) = std::max(TmaxCoh[c]*Klcmean, E_gmin)*(Kunlc[l]/sumKunlc);
+        outputExtraction(c,l) = std::max(TmaxCoh[c]*Klcmean, E_gmin_day)*(Kunlc[l]/sumKunlc);
       }
       rootCrownPsi = averagePsi(psiSoil, V(c,_), Exp_Extract[c], Psi_Extract[c]);
     } else {
@@ -345,7 +345,7 @@ void transpirationBasic(List transpOutput, List x, NumericVector meteovec,
       double Klcmean = sum(Klc*RHOPcohV);
       for(int l=0;l<nlayers;l++) {
         for(int j = 0;j<numCohorts;j++) {
-          ExtractionPoolsCoh(j,l) = std::max(TmaxCoh[c]*Klcmean, E_gmin)*(Kunlc(j,l)/sumKunlc);
+          ExtractionPoolsCoh(j,l) = std::max(TmaxCoh[c]*Klcmean, E_gmin_day)*(Kunlc(j,l)/sumKunlc);
         }
         outputExtraction(c,l) = sum(ExtractionPoolsCoh(_,l)); // Sum extraction from all pools (layer l)
       }
@@ -552,7 +552,7 @@ void transpirationBasic(List transpOutput, List x, NumericVector meteovec,
 //'       \item{\code{"Transpiration"}: Transpirated water (in mm) corresponding to each cohort.}
 //'       \item{\code{"GrossPhotosynthesis"}: Gross photosynthesis (in gC/m2) corresponding to each cohort.}
 //'       \item{\code{"psi"}: Water potential (in MPa) of the plant cohort (average over soil layers).}
-//'       \item{\code{"DDS"}: Daily drought stress [0-1] (relative whole-plant conductance).}
+//'       \item{\code{"DDS"}: Daily drought stress \[0-1\] (relative whole-plant conductance).}
 //'     }
 //'   When using \code{transp_transpirationSperry} or \code{transp_transpirationSureau}, element \code{"Plants"} includes:
 //'     \itemize{
@@ -572,7 +572,7 @@ void transpirationBasic(List transpOutput, List x, NumericVector meteovec,
 //'       \item{\code{"LeafPsiMin_SH"}: Minimum (predawn) water potential (in MPa) at shade leaves.}
 //'       \item{\code{"LeafPsiMax_SH"}: Maximum (midday) water potential (in MPa) at shade leaves.}
 //'       \item{\code{"dEdP"}: Overall soil-plant conductance (derivative of the supply function).}
-//'       \item{\code{"DDS"}: Daily drought stress [0-1] (relative whole-plant conductance).}
+//'       \item{\code{"DDS"}: Daily drought stress \[0-1\] (relative whole-plant conductance).}
 //'       \item{\code{"StemRWC"}: Relative water content of stem tissue (including symplasm and apoplasm).}
 //'       \item{\code{"LeafRWC"}: Relative water content of leaf tissue (including symplasm and apoplasm).}
 //'       \item{\code{"LFMC"}: Live fuel moisture content (in percent of dry weight).}
@@ -619,11 +619,11 @@ void transpirationBasic(List transpOutput, List x, NumericVector meteovec,
 //'       \item{\code{"RootPsi"}: A data frame with root crown water potential (in MPa) for each plant cohort during each time step.}
 //'       \item{\code{"StemPsi"}: A data frame with stem water potential (in MPa) for each plant cohort during each time step.}
 //'       \item{\code{"LeafPsi"}: A data frame with leaf (average) water potential (in MPa) for each plant cohort during each time step. }
-//'       \item{\code{"StemPLC"}: A data frame with the proportion loss of conductance [0-1] for each plant cohort during each time step. }
-//'       \item{\code{"StemRWC"}: A data frame with the (average) relative water content of stem tissue [0-1] for each plant cohort during each time step. }
-//'       \item{\code{"LeafRWC"}: A data frame with the relative water content of leaf tissue [0-1] for each plant cohort during each time step. }
-//'       \item{\code{"StemSympRWC"}: A data frame with the (average) relative water content of symplastic stem tissue [0-1] for each plant cohort during each time step. }
-//'       \item{\code{"LeafSympRWC"}: A data frame with the relative water content of symplastic leaf tissue [0-1] for each plant cohort during each time step. }
+//'       \item{\code{"StemPLC"}: A data frame with the proportion loss of conductance \[0-1\] for each plant cohort during each time step. }
+//'       \item{\code{"StemRWC"}: A data frame with the (average) relative water content of stem tissue \[0-1\] for each plant cohort during each time step. }
+//'       \item{\code{"LeafRWC"}: A data frame with the relative water content of leaf tissue \[0-1\] for each plant cohort during each time step. }
+//'       \item{\code{"StemSympRWC"}: A data frame with the (average) relative water content of symplastic stem tissue \[0-1\] for each plant cohort during each time step. }
+//'       \item{\code{"LeafSympRWC"}: A data frame with the relative water content of symplastic leaf tissue \[0-1\] for each plant cohort during each time step. }
 //'       \item{\code{"PWB"}: A data frame with plant water balance (extraction - transpiration).}
 //'     }
 //'   }
